@@ -113,4 +113,4 @@ GType                   e_data_book_get_type               (void);
 
 G_END_DECLS
 
-#endif /* ! __E_DATA_BOOK_H__ */
+#endif /* __E_DATA_BOOK_H__ */
