@@ -2,7 +2,7 @@
 /*
  * Evolution calendar recurrence rule functions
  *
- * Copyright (C) 2000 Ximian, Inc.
+ * Copyright (C) 1999-2008 Novell, Inc. (www.novell.com)
  *
  * Author: Damon Chaplin <damon@ximian.com>
  *
@@ -17,7 +17,7 @@
  *
  * You should have received a copy of the GNU Lesser General Public License
  * along with this program; if not, write to the Free Software
- * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307, USA.
+ * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
  */
 
 #ifndef E_CAL_RECUR_H
@@ -33,7 +33,7 @@ typedef gboolean (* ECalRecurInstanceFn) (ECalComponent *comp,
 					 time_t        instance_end,
 					 gpointer      data);
 
-typedef icaltimezone* (* ECalRecurResolveTimezoneFn)	(const char   *tzid,
+typedef icaltimezone* (* ECalRecurResolveTimezoneFn)	(const gchar   *tzid,
 							 gpointer      data);
 
 void	e_cal_recur_generate_instances	(ECalComponent		*comp,
@@ -47,10 +47,10 @@ void	e_cal_recur_generate_instances	(ECalComponent		*comp,
 
 /* Localized nth-day-of-month strings. (Use with _() ) */
 #ifdef G_OS_WIN32
-extern const char **e_cal_get_recur_nth (void);
+extern const gchar **e_cal_get_recur_nth (void);
 #define e_cal_recur_nth (e_cal_get_recur_nth ())
 #else
-extern const char *e_cal_recur_nth[31];
+extern const gchar *e_cal_recur_nth[31];
 #endif
 
 G_END_DECLS
