@@ -192,6 +192,7 @@ camel_folder_init (gpointer object, gpointer klass)
 	folder->priv = g_malloc0(sizeof(*folder->priv));
 	folder->priv->frozen = 0;
 	folder->priv->changed_frozen = camel_folder_change_info_new();
+	folder->priv->async_rec_locks = FALSE;
 	g_static_rec_mutex_init(&folder->priv->lock);
 	g_static_mutex_init(&folder->priv->change_lock);
 }
@@ -222,6 +223,12 @@ camel_folder_finalize (CamelObject *object)
 	g_free(p);
 }
 
+void
+camel_folder_set_lock_async (CamelFolder *folder, gboolean async)
+{
+	folder->priv->async_rec_locks = async;
+}
+
 CamelType
 camel_folder_get_type (void)
 {
@@ -399,7 +406,7 @@ folder_getv(CamelObject *object, CamelException *ex, CamelArgGetV *args)
 								deleted++;
 							if (flags & CAMEL_MESSAGE_JUNK) {
 								junked++;
-								if (! (flags & CAMEL_MESSAGE_DELETED))
+								if (!(flags & CAMEL_MESSAGE_DELETED))
 									junked_not_deleted++;
 							}
 							if ((flags & (CAMEL_MESSAGE_DELETED|CAMEL_MESSAGE_JUNK)) == 0)
