@@ -69,10 +69,10 @@ static GSList *local_folder_properties;
 #define CF_CLASS(so) CAMEL_FOLDER_CLASS (CAMEL_OBJECT_GET_CLASS(so))
 #define CLOCALS_CLASS(so) CAMEL_STORE_CLASS (CAMEL_OBJECT_GET_CLASS(so))
 
-static int local_getv(CamelObject *object, CamelException *ex, CamelArgGetV *args);
-static int local_setv(CamelObject *object, CamelException *ex, CamelArgV *args);
+static gint local_getv(CamelObject *object, CamelException *ex, CamelArgGetV *args);
+static gint local_setv(CamelObject *object, CamelException *ex, CamelArgV *args);
 
-static int local_lock(CamelLocalFolder *lf, CamelLockType type, CamelException *ex);
+static gint local_lock(CamelLocalFolder *lf, CamelLockType type, CamelException *ex);
 static void local_unlock(CamelLocalFolder *lf);
 
 static void local_refresh_info(CamelFolder *folder, CamelException *ex);
@@ -80,14 +80,14 @@ static void local_refresh_info(CamelFolder *folder, CamelException *ex);
 static void local_sync(CamelFolder *folder, gboolean expunge, CamelException *ex);
 static void local_expunge(CamelFolder *folder, CamelException *ex);
 
-static GPtrArray *local_search_by_expression(CamelFolder *folder, const char *expression, CamelException *ex);
-static guint32 local_count_by_expression(CamelFolder *folder, const char *expression, CamelException *ex);
-static GPtrArray *local_search_by_uids(CamelFolder *folder, const char *expression, GPtrArray *uids, CamelException *ex);
+static GPtrArray *local_search_by_expression(CamelFolder *folder, const gchar *expression, CamelException *ex);
+static guint32 local_count_by_expression(CamelFolder *folder, const gchar *expression, CamelException *ex);
+static GPtrArray *local_search_by_uids(CamelFolder *folder, const gchar *expression, GPtrArray *uids, CamelException *ex);
 static void local_search_free(CamelFolder *folder, GPtrArray * result);
 static GPtrArray * local_get_uncached_uids (CamelFolder *folder, GPtrArray * uids, CamelException *ex);
 
 static void local_delete(CamelFolder *folder);
-static void local_rename(CamelFolder *folder, const char *newname);
+static void local_rename(CamelFolder *folder, const gchar *newname);
 
 static void local_finalize(CamelObject * object);
 
@@ -168,9 +168,9 @@ local_finalize(CamelObject * object)
 	g_free(local_folder->index_path);
 
 	camel_folder_change_info_free(local_folder->changes);
-	
+
 	g_mutex_free(local_folder->priv->search_lock);
-	
+
 	g_free(local_folder->priv);
 }
 
@@ -184,7 +184,7 @@ camel_local_folder_get_type(void)
 	static CamelType camel_local_folder_type = CAMEL_INVALID_TYPE;
 
 	if (camel_local_folder_type == CAMEL_INVALID_TYPE) {
-		int i;
+		gint i;
 
 		parent_class = (CamelFolderClass *)camel_folder_get_type();
 		camel_local_folder_type = camel_type_register(camel_folder_get_type(), "CamelLocalFolder",
@@ -195,7 +195,7 @@ camel_local_folder_get_type(void)
 							     (CamelObjectInitFunc) local_init,
 							     (CamelObjectFinalizeFunc) local_finalize);
 
-		for (i=0;i<sizeof(local_property_list)/sizeof(local_property_list[0]);i++) {
+		for (i = 0; i < G_N_ELEMENTS (local_property_list); i++) {
 			local_property_list[i].description = _(local_property_list[i].description);
 			local_folder_properties = g_slist_prepend(local_folder_properties, &local_property_list[i]);
 		}
@@ -205,21 +205,21 @@ camel_local_folder_get_type(void)
 }
 
 CamelLocalFolder *
-camel_local_folder_construct(CamelLocalFolder *lf, CamelStore *parent_store, const char *full_name, guint32 flags, CamelException *ex)
+camel_local_folder_construct(CamelLocalFolder *lf, CamelStore *parent_store, const gchar *full_name, guint32 flags, CamelException *ex)
 {
 	CamelFolderInfo *fi;
 	CamelFolder *folder;
-	const char *root_dir_path;
-	char *name;
-	char *tmp, *statepath;
+	const gchar *root_dir_path;
+	gchar *name;
+	gchar *tmp, *statepath;
 #ifndef G_OS_WIN32
-	char folder_path[PATH_MAX];
+	gchar folder_path[PATH_MAX];
 	struct stat st;
 #endif
-	int forceindex, len;
+	gint forceindex, len;
 	CamelURL *url;
 	CamelLocalStore *ls = (CamelLocalStore *)parent_store;
-	
+
 	folder = (CamelFolder *)lf;
 
 	name = g_path_get_basename(full_name);
@@ -270,7 +270,7 @@ camel_local_folder_construct(CamelLocalFolder *lf, CamelStore *parent_store, con
 	/* if we have no/invalid index file, force it */
 	forceindex = camel_text_index_check(lf->index_path) == -1;
 	if (lf->flags & CAMEL_STORE_FOLDER_BODY_INDEX) {
-		int flag = O_RDWR|O_CREAT;
+		gint flag = O_RDWR|O_CREAT;
 
 		if (forceindex)
 			flag |= O_TRUNC;
@@ -299,7 +299,7 @@ camel_local_folder_construct(CamelLocalFolder *lf, CamelStore *parent_store, con
 				camel_object_unref (CAMEL_OBJECT (folder));
 				g_free(name);
 				return NULL;
-			}		
+			}
 		}
 	}
 
@@ -337,7 +337,7 @@ camel_local_folder_construct(CamelLocalFolder *lf, CamelStore *parent_store, con
 
 /* lock the folder, may be called repeatedly (with matching unlock calls),
    with type the same or less than the first call */
-int camel_local_folder_lock(CamelLocalFolder *lf, CamelLockType type, CamelException *ex)
+gint camel_local_folder_lock(CamelLocalFolder *lf, CamelLockType type, CamelException *ex)
 {
 	if (lf->locked > 0) {
 		/* lets be anal here - its important the code knows what its doing */
@@ -354,7 +354,7 @@ int camel_local_folder_lock(CamelLocalFolder *lf, CamelLockType type, CamelExcep
 }
 
 /* unlock folder */
-int camel_local_folder_unlock(CamelLocalFolder *lf)
+gint camel_local_folder_unlock(CamelLocalFolder *lf)
 {
 	g_assert(lf->locked>0);
 	lf->locked--;
@@ -364,11 +364,11 @@ int camel_local_folder_unlock(CamelLocalFolder *lf)
 	return 0;
 }
 
-static int
+static gint
 local_getv(CamelObject *object, CamelException *ex, CamelArgGetV *args)
 {
 	CamelFolder *folder = (CamelFolder *)object;
-	int i;
+	gint i;
 	guint32 tag;
 
 	for (i=0;i<args->argc;i++) {
@@ -379,7 +379,8 @@ local_getv(CamelObject *object, CamelException *ex, CamelArgGetV *args)
 		switch (tag & CAMEL_ARG_TAG) {
 		case CAMEL_OBJECT_ARG_DESCRIPTION:
 			if (folder->description == NULL) {
-				char *tmp, *path;
+				const gchar *tmp;
+				gchar *path;
 
 				/* check some common prefixes to shorten the name */
 				tmp = ((CamelService *)folder->parent_store)->url->path;
@@ -402,7 +403,7 @@ local_getv(CamelObject *object, CamelException *ex, CamelArgGetV *args)
 									      ((CamelService *)folder->parent_store)->url->protocol);
 				else
 					/* a full path + protocol */
-					folder->description = g_strdup_printf(_("%s (%s)"), path, 
+					folder->description = g_strdup_printf(_("%s (%s)"), path,
 									      ((CamelService *)folder->parent_store)->url->protocol);
 			}
 			*arg->ca_str = folder->description;
@@ -434,10 +435,10 @@ local_getv(CamelObject *object, CamelException *ex, CamelArgGetV *args)
 	return ((CamelObjectClass *)parent_class)->getv(object, ex, args);
 }
 
-static int
+static gint
 local_setv(CamelObject *object, CamelException *ex, CamelArgV *args)
 {
-	int i;
+	gint i;
 	guint32 tag;
 
 	for (i=0;i<args->argc;i++) {
@@ -465,7 +466,7 @@ local_setv(CamelObject *object, CamelException *ex, CamelArgV *args)
 	return ((CamelObjectClass *)parent_class)->setv(object, ex, args);
 }
 
-static int
+static gint
 local_lock(CamelLocalFolder *lf, CamelLockType type, CamelException *ex)
 {
 	return 0;
@@ -483,24 +484,15 @@ local_refresh_info(CamelFolder *folder, CamelException *ex)
 {
 	CamelLocalFolder *lf = (CamelLocalFolder *)folder;
 
-	/* 
-	 * Banner: This is a very very ugly hack to get over the summary mismatch. This needs to 
-	 * be done better. Im postponing this post-disk summary.
-	 * */
-
-	CAMEL_FOLDER_REC_LOCK(folder, lock);
-
 	if (camel_local_summary_check((CamelLocalSummary *)folder->summary, lf->changes, ex) == -1) {
-		CAMEL_FOLDER_REC_UNLOCK(folder, lock);
 		return;
 	}
 
-	CAMEL_FOLDER_REC_UNLOCK(folder, lock);
 	if (camel_folder_change_info_changed(lf->changes)) {
 		camel_object_trigger_event((CamelObject *)folder, "folder_changed", lf->changes);
 		camel_folder_change_info_clear(lf->changes);
 	}
-	
+
 }
 
 static GPtrArray *
@@ -547,7 +539,7 @@ static void
 local_delete(CamelFolder *folder)
 {
 	CamelLocalFolder *lf = (CamelLocalFolder *)folder;
-	
+
 	if (lf->index)
 		camel_index_delete(lf->index);
 
@@ -555,10 +547,10 @@ local_delete(CamelFolder *folder)
 }
 
 static void
-local_rename(CamelFolder *folder, const char *newname)
+local_rename(CamelFolder *folder, const gchar *newname)
 {
 	CamelLocalFolder *lf = (CamelLocalFolder *)folder;
-	char *statepath;
+	gchar *statepath;
 	CamelLocalStore *ls = (CamelLocalStore *)folder->parent_store;
 
 	d(printf("renaming local folder paths to '%s'\n", newname));
@@ -585,7 +577,7 @@ local_rename(CamelFolder *folder, const char *newname)
 }
 
 static GPtrArray *
-local_search_by_expression(CamelFolder *folder, const char *expression, CamelException *ex)
+local_search_by_expression(CamelFolder *folder, const gchar *expression, CamelException *ex)
 {
 	CamelLocalFolder *local_folder = CAMEL_LOCAL_FOLDER(folder);
 	GPtrArray *matches;
@@ -605,7 +597,7 @@ local_search_by_expression(CamelFolder *folder, const char *expression, CamelExc
 }
 
 static guint32
-local_count_by_expression(CamelFolder *folder, const char *expression, CamelException *ex)
+local_count_by_expression(CamelFolder *folder, const gchar *expression, CamelException *ex)
 {
 	CamelLocalFolder *local_folder = CAMEL_LOCAL_FOLDER(folder);
 	gint matches;
@@ -625,7 +617,7 @@ local_count_by_expression(CamelFolder *folder, const char *expression, CamelExce
 }
 
 static GPtrArray *
-local_search_by_uids(CamelFolder *folder, const char *expression, GPtrArray *uids, CamelException *ex)
+local_search_by_uids(CamelFolder *folder, const gchar *expression, GPtrArray *uids, CamelException *ex)
 {
 	CamelLocalFolder *local_folder = CAMEL_LOCAL_FOLDER(folder);
 	GPtrArray *matches;
